summaryrefslogtreecommitdiff
path: root/service/container.go
diff options
context:
space:
mode:
authorWolfy-J <[email protected]>2018-06-13 14:07:05 +0300
committerWolfy-J <[email protected]>2018-06-13 14:07:05 +0300
commitca95f67317bcf8972b9e669869338a7dc09bf06d (patch)
tree4d199ceb8a78675242fef21bd87efb5a78b04029 /service/container.go
parentc8e8afe79611941ce50453ee7dfae82d7915e9c4 (diff)
more upload tests
Diffstat (limited to 'service/container.go')
-rw-r--r--service/container.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/service/container.go b/service/container.go
index 56350be7..7c7633e7 100644
--- a/service/container.go
+++ b/service/container.go
@@ -95,7 +95,7 @@ func (c *container) Get(target string) (svc Service, status int) {
return nil, StatusUndefined
}
// Configure configures all underlying services with given configuration.
func (c *container) Configure(cfg Config) error {
for _, e := range c.services {
if e.getStatus() >= StatusConfigured {
@@ -108,7 +108,7 @@ func (c *container) Configure(cfg Config) error {
continue
}
- ok, err := e.svc.Configure(segment, c)
+ ok, err := e.svc.Init(segment, c)
if err != nil {
return errors.Wrap(err, fmt.Sprintf("[%s]", e.name))
} else if ok {
@@ -95,7 +95,7 @@ func (c *container) Get(target string) (svc Service, status int) {
return nil, StatusUndefined
}
-// Configure configures all underlying services with given configuration.
+// Init configures all underlying services with given configuration.
func (c *container) Configure(cfg Config) error {
for _, e := range c.services {